@@ -1,11 +1,18 @@
+use crate::common::Loc;
 use serde::{Deserialize, Serialize};
 use swc_common::ast_serde;
 
-use crate::common::Loc;
-
-#[derive(Debug, Clone, PartialEq)]
-#[ast_serde("BaseComment")]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Serialize, Deserialize)]
+pub enum CommentType {
+    #[serde(rename = "CommentLine")]
+    Line,
+    #[serde(rename = "CommentBlock")]
+    Block,
+}
+#[derive(Debug, Clone, PartialEq, Serialize, Deserialize)]
 pub struct BaseComment {
+    #[serde(rename = "type")]
+    pub type_: CommentType,
     pub value: String,
     pub start: usize,
     pub end: usize,
